@@ -24,16 +24,22 @@ from plinth import cfg
 
 from . import utils
 
-__all__ = ['init']
+version = 1
 
-depends = ['plinth.modules.apps', 'plinth.modules.names']
+depends = ['apps', 'names']
+
+title = _('Public Visibility (PageKite)')
 
 
 def init():
     """Intialize the PageKite module"""
     menu = cfg.main_menu.get('apps:index')
-    menu.add_urlname(_('Public Visibility (PageKite)'),
-                     'glyphicon-flag', 'pagekite:index', 800)
+    menu.add_urlname(title, 'glyphicon-flag', 'pagekite:index', 800)
 
     # Register kite name with Name Services module.
     utils.update_names_module(initial_registration=True)
+
+
+def setup(helper, old_version=None):
+    """Install and configure the module."""
+    helper.install(['pagekite'])
