@@ -21,9 +21,9 @@ URLs for the repro module.
 
 from django.conf.urls import url
 
-from . import views
+from plinth.modules.repro import ReproServiceView
 
 
 urlpatterns = [
-    url(r'^apps/repro/$', views.index, name='index'),
+    url(r'^apps/repro/$', ReproServiceView.as_view(), name='index'),
 ]
