@@ -20,28 +20,46 @@ Plinth module to configure reStore.
 """
 
 from django.utils.translation import ugettext_lazy as _
-from plinth import action_utils, cfg
+
+from plinth import cfg
 from plinth import service as service_module
+from plinth.utils import format_lazy
+
+
+version = 1
+
+depends = ['apps']
+
+title = _('Unhosted Storage (reStore)')
+
+description = [
+    format_lazy(
+        _('reStore is a server for <a href=\'https://unhosted.org/\'>'
+          'unhosted</a> web applications.  The idea is to uncouple web '
+          'applications from data.  No matter where a web application is '
+          'served from, the data can be stored on an unhosted storage '
+          'server of user\'s choice.  With reStore, your {box_name} becomes '
+          'your unhosted storage server.'), box_name=_(cfg.box_name)),
+
+    _('You can create and edit accounts in the '
+      '<a href=\'/restore/\'>reStore web-interface</a>.')
+]
 
 service = None
 
-__all__ = ['init']
-
-depends = ['plinth.modules.apps']
+managed_services = ['node-restore']
 
 
 def init():
     """Initialize the reStore module."""
     menu = cfg.main_menu.get('apps:index')
-    menu.add_urlname(_('Unhosted Storage (reStore)'), 'glyphicon-hdd',
-                     'restore:index', 750)
+    menu.add_urlname(title, 'glyphicon-hdd', 'restore:index', 750)
 
     global service
     service = service_module.Service(
-        'node-restore', _('reStore'), ['http', 'https'],
-        is_external=False, enabled=is_enabled())
+        managed_services[0], title, ports=['http', 'https'], is_external=False)
 
 
-def is_enabled():
-    """Return whether the module is enabled."""
-    return action_utils.service_is_enabled('node-restore')
+def setup(helper, old_version=None):
+    """Install and configure the module."""
+    helper.install(['node-restore'])
