@@ -21,9 +21,13 @@ URLs for the reStore module.
 
 from django.conf.urls import url
 
-from . import views
+from plinth.views import ServiceView
+from plinth.modules import restore
 
 
 urlpatterns = [
-    url(r'^apps/restore/$', views.index, name='index'),
+    url(r'^apps/restore/$', ServiceView.as_view(
+            service_id=restore.managed_services[0],
+            description=restore.description
+        ), name='index'),
 ]
