@@ -21,12 +21,26 @@ Plinth module to configure Shaarli.
 
 from django.utils.translation import ugettext_lazy as _
 
+from plinth import actions
 from plinth import action_utils
 from plinth import cfg
 from plinth import service as service_module
 
 
-depends = ['plinth.modules.apps']
+version = 1
+
+depends = ['apps']
+
+title = _('Bookmarks (Shaarli)')
+
+description = [
+    _('Shaarli allows you to save and share bookmarks.'),
+
+    _('When enabled, Shaarli will be available from <a href="/shaarli">'
+      '/shaarli</a> path on the web server. Note that Shaarli only supports a '
+      'single user account, which you will need to setup on the initial '
+      'visit.'),
+]
 
 service = None
 
@@ -34,15 +48,31 @@ service = None
 def init():
     """Initialize the module."""
     menu = cfg.main_menu.get('apps:index')
-    menu.add_urlname(_('Bookmarks (Shaarli)'), 'glyphicon-bookmark',
-                     'shaarli:index', 350)
+    menu.add_urlname(title, 'glyphicon-bookmark', 'shaarli:index', 350)
 
     global service
     service = service_module.Service(
-        'shaarli', _('Shaarli'), ['http', 'https'],
-        is_external=True, enabled=is_enabled())
+        'shaarli', title, ports=['http', 'https'], is_external=True,
+        is_enabled=is_enabled, enable=enable, disable=disable)
+
+
+def setup(helper, old_version=None):
+    """Install and configure the module."""
+    helper.install(['shaarli'])
+    helper.call('post', service.notify_enabled, None, True)
+
 
 
 def is_enabled():
     """Return whether the module is enabled."""
     return action_utils.webserver_is_enabled('shaarli')
+
+
+def enable():
+    """Enable the module."""
+    actions.superuser_run('shaarli', ['enable'])
+
+
+def disable():
+    """Enable the module."""
+    actions.superuser_run('shaarli', ['disable'])
