@@ -19,8 +19,29 @@
 Plinth module for system section page
 """
 
-from . import system
-from .system import init
+from django.utils.translation import ugettext_lazy as _
+
+from plinth import cfg
+from plinth.utils import format_lazy
 
 
-__all__ = ['system', 'init']
+version = 1
+
+is_essential = True
+
+title = _('System Configuration')
+
+description = [
+    format_lazy(
+        _('Here you can administrate the underlying system of your '
+          '{box_name}.'), box_name=_(cfg.box_name)),
+
+    format_lazy(
+        _('The options affect the {box_name} at its most general level, '
+          'so be careful!'), box_name=_(cfg.box_name))
+]
+
+
+def init():
+    """Initialize the system module"""
+    cfg.main_menu.add_urlname(title, 'glyphicon-cog', 'system:index', 100)
