@@ -21,8 +21,9 @@ URLs for the XMPP module
 
 from django.conf.urls import url
 
-from . import views
+from plinth.modules.xmpp import EjabberdServiceView
+
 
 urlpatterns = [
-    url(r'^apps/xmpp/$', views.index, name='index'),
+    url(r'^apps/xmpp/$', EjabberdServiceView.as_view(), name='index'),
 ]
